@@ -6,12 +6,16 @@
 #'
 #' @param region An object of class `sf` with a `POLYGON` or `MULTIPOLYGON` geometry type
 #' @param raster An object of class SpatRaster (terra)
-#' @param dist_fun Distance measure used. This function uses the `philentropy::distance` function in the background. Run `philentropy::getDistMethods()` to find possible distance measures.
+#' @param dist_fun Distance measure used. This function uses `philentropy::distance` (run `philentropy::getDistMethods()` to find possible distance measures) or `proxy::dist` (run `names(proxy::pr_DB$get_entries())` to find possible distance measures) in the background.
+#' It is also possible to use `"dtw"` (dynamic time warping)
 #' @param sample_size Proportion of the cells inside of each region to be used in calculations. Value between 0 and 1.
 #' It is also possible to specify an integer larger than 1, in which case the specified number of cells
 #' of each region will be used in calculations.
 #' @param unit a character string specifying the logarithm unit that should be used to
 #' compute distances that depend on log computations.
+#' @param na.rm Whether NA values should be stripped from the calculations.
+#' @param ... Additional arguments for `philentropy::dist_one_one`, `proxy::dist`, or `dtwclust::dtw_basic`.
+#' When `dist_fun = "dtw"` is used, `ndim` should be set to specify how many dimension the input raster time-series has.
 #'
 #' @return A vector with the distinction values
 #' @export
@@ -33,7 +37,7 @@
 #'     plot(vr["dis"], add = TRUE)
 #'  }
 #' }
-reg_distinction = function(region, raster, dist_fun = "euclidean", sample_size = 1, unit = "log2") {
+reg_distinction = function(region, raster, dist_fun = "euclidean", sample_size = 1, unit = "log2", na.rm = FALSE, ...) {
   # set.seed(32)
   v = terra::vect(region)
   dis = vector(mode = "numeric", length = length(v))
@@ -41,22 +45,26 @@ reg_distinction = function(region, raster, dist_fun = "euclidean", sample_size =
   for (i in seq_len(length(v))){
     sum_dist = 0
     n_elem = 0
-    vals_i = as.matrix(terra::extract(raster, v[i])[-1])
+    vals_i = terra::extract(raster, v[i], ID = FALSE, raw = TRUE)
     if (sample_size < 1){
       vals_i = vals_i[sample(nrow(vals_i), size = sample_size * nrow(vals_i)), , drop = FALSE]
     } else if (sample_size > 1) {
       vals_i = vals_i[sample(nrow(vals_i), size = min(c(nrow(vals_i), sample_size))), , drop = FALSE]
     }
     for (j in setdiff(seq_len(length(v)), i)){
-      vals_j = as.matrix(terra::extract(raster, v[j])[-1])
+      vals_j = terra::extract(raster, v[j], ID = FALSE, raw = TRUE)
       if (sample_size < 1){
         vals_j = vals_j[sample(nrow(vals_j), size = sample_size * nrow(vals_j)), , drop = FALSE]
       } else if (sample_size > 1) {
         vals_j = vals_j[sample(nrow(vals_j), size = min(c(nrow(vals_j), sample_size))), , drop = FALSE]
       }
-      dist_mat = philentropy::dist_many_many(vals_i, vals_j, method = dist_fun, testNA = FALSE, unit = unit)
-      sum_dist = sum_dist + sum(dist_mat)
-      n_elem = n_elem + length(dist_mat)
+      dist_mat = universal_dist_many_many(vals_i, vals_j, dist_fun = dist_fun, ...)
+      sum_dist = sum_dist + sum(dist_mat, na.rm = na.rm)
+      if (na.rm){
+        n_elem = n_elem + sum(!is.na(dist_mat))
+      } else {
+        n_elem = n_elem + length(dist_mat)
+      }
     }
     dis[i] = sum_dist / n_elem
   }
